PointwiseHingeLoss
==================

.. currentmodule:: pykeen.losses

.. autoclass:: PointwiseHingeLoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PointwiseHingeLoss.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
